@@ -1,15 +1,16 @@
-"""IGDB wrapper module for the api v3 with Apicalypse"""
+"""IGDB wrapper module for the api v4 with Apicalypse"""
 
-from requests import get, post
+from requests import post
+from requests.models import Request, Response
 
-API_URL = "https://api-v3.igdb.com/"
+API_URL = "https://api.igdb.com/v4/"
 
 class IGDBWrapper:
-    def __init__(self, user_key=None):
-        self.user_key = user_key
-        self.endpoint = ''
+    def __init__(self, client_id:str, auth_token:str) -> None:
+        self.client_id = client_id
+        self.auth_token = auth_token
 
-    def api_request(self, endpoint=None, query=None):
+    def api_request(self, endpoint:str, query:str) -> Response:
         """
         Takes an endpoint and the Apicalypse query and returns the api response as a byte string.
         """
@@ -22,16 +23,17 @@ class IGDBWrapper:
         return response.content
 
     @staticmethod
-    def _build_url(endpoint=''):
-        return f'{API_URL}{endpoint}'
+    def _build_url(endpoint:str='') -> str:
+        return ('%s%s' % (API_URL, endpoint))
 
-    def _compose_request(self, query=None):
+    def _compose_request(self, query:str) -> Request:
         if not query:
             raise Exception('No query provided!\nEither provide an inline query following Apicalypse\'s syntax or an Apicalypse object')
        
         request_params = {
             'headers': {
-                'user-key': self.user_key
+                'Client-ID': self.client_id,
+                'Authorization': ('Bearer %s' % (self.auth_token)),
             }
         }
 
